/* Revision History
 * 2015-02-07 - MisterCardholder
 *   Initial Release
 */

/*
 * The Legend of Korra (PC) WTA File Structure
 *
 * +-------------------------------------+
 * | File Header                         |
 * | wta_header_t                        |
 * +-------------------------------------+
 * | Array of Texture Offsets            |
 * | wmb3_vertexHeader_t                 |
 * +-------------------------------------+
 * | Array of Texture Sizes              |
 * | wmb3_vertexHeader_t                 |
 * +-------------------------------------+
 * | Array of Flags (?)                  |
 * |                                     |
 * +-------------------------------------+
 * | Array of Texture Identifier         |
 * | wta_textureIdentifier_t             |
 * +-------------------------------------+
 *
 * Notes:
 *
 * The WTA files contain metadata for the WTP files (which are just a series
 * of dds files joined with a bit of zero-padding between them).
 *
 */

#include <stdint.h>

typedef struct wta_header_s {
	char		fourCC[4]; 						// "WTB\0"
	uint32_t	unknown04;						// Always 1 (a version?)
	uint32_t	textureCount;
	uint32_t	textureOffsetArrayOffset;		// see: wta_textureOffset_t
	uint32_t	textureSizeArrayOffset;			// see: wta_textureSize_t
	uint32_t	unknownArrayOffset;				// Possibly flags for each texture
	uint32_t	textureIdentifierArrayOffset;	// see: wta_textureIdentifier_t
} wta_header_t;

// The offset in the corresponding wtp file where a given texture starts
typedef uint32_t wta_textureOffset_t;

// The size (in bytes) of the given texture in the corresponding wtp file
typedef uint32_t wta_textureSize_t;

// A unique identifier for each texture (maybe derrived from a checksum or hash?)
typedef uint32_t wta_textureIdentifier_t;
